@@ -558,7 +558,7 @@ def fit(data_file, fit_range, components_list, comp_constraints, comp_names, com
                     elif param_name == 'center':
                         param.set(expr='{}+{}*{}'.format(iso_param_name, index, mas_freq/larmor_freq))
                     elif param_name == 'amplitude':
-                        param.set(value=component[param_name])
+                        param.set(value=component[param_name], min=0)
                 compiled_components.append(pseudo_voigt)
     # build model containing all generated components
     model = compiled_components[0]
